==> cypress-2021.2.0.zip: cypress/sidebar.php <==
<aside class="clear">
    <header>
        <!-- Logo -->
        <h1 class="logo">
            <a href="<?php echo home_url(); ?>">
                <div><?php if ( get_theme_mod( 'cypress_theme_logo' ) ) : echo '<img src="' . get_theme_mod( 'cypress_theme_logo' ) . '" />'; else : echo '<img src="' . get_template_directory_uri() . '/images/logo.png" width="145">'; endif; ?></div>
            </a>
            <div class="text"><?php echo bloginfo('name'); ?></div>
        </h1>
        <div class="info collapse" id="info">
            <!-- Subtitle -->
            <div class="subtitle">
                <p><?php bloginfo('description'); ?></p>
            </div>
            <!-- Navigation -->
            <nav class="main-nav">
                <?php wp_nav_menu( array( 'container' => false, 'menu_id' => 'menu-navigation', 'menu_class'=>'', 'theme_location'=>'primary-menu' ) ); ?>
            </nav>
            <div class="social">
                <p>
                    <?php if ( get_theme_mod('cypress_social_facebook') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_facebook'); ?>"><i class="fab fa-facebook"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_linkedin') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_linkedin'); ?>"><i class="fab fa-linkedin"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_twitter') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_twitter'); ?>"><i class="fab fa-twitter"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_microblog') ) : ?>
                        <a href="<?php echo get_theme_mod('cypress_social_microblog'); ?>"><i class="fab fa-microblog"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_instagram') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_instagram'); ?>"><i class="fab fa-instagram"></i></a>
                    <?php endif; ?>
                </p>
            </div>
        </div>
        <!-- Mobile Menu -->
        <div class="mobile-menu">
            <span class="mobile-logo">

            </span>
        </div>
        <!-- Hamburger -->
        <a href="#" class="nav-toggle">
        	<span class="sr-only">Toggle navigation</span>
        	<span class="icon-bar"></span>
        	<span class="icon-bar"></span>
        	<span class="icon-bar"></span>
        </a>
        <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#info">
            <i class="material-icons">info_outline</i>
        </button>
    </header>
</aside>

==> cypress-2021.5.1.zip: cypress/sidebar.php <==
<aside class="clear">
    <header>
        <!-- Logo -->
        <h1 class="logo">
            <a href="<?php echo home_url(); ?>">
                <div><?php if ( get_theme_mod( 'cypress_theme_logo' ) ) : echo '<img src="' . get_theme_mod( 'cypress_theme_logo' ) . '" />'; else : echo '<img src="' . get_template_directory_uri() . '/images/logo.png" width="145">'; endif; ?></div>
            </a>
            <div class="text"><?php echo bloginfo('name'); ?></div>
        </h1>
        <div class="info collapse" id="info">
            <!-- Subtitle -->
            <div class="subtitle">
                <p><?php bloginfo('description'); ?></p>
            </div>
            <!-- Navigation -->
            <nav class="main-nav">
                <?php wp_nav_menu( array( 'container' => false, 'menu_id' => 'menu-navigation', 'menu_class'=>'', 'theme_location'=>'primary-menu' ) ); ?>
            </nav>
            <?php if ( is_active_sidebar( 'cypress_sidebar_widgets' ) ) : ?>
                <div id="primary-sidebar" class="primary-sidebar widget-area" role="complementary">
                    <?php dynamic_sidebar( 'cypress_sidebar_widgets' ); ?>
                </div><!-- #primary-sidebar -->
            <?php endif; ?>
            <div class="social">
                <p>
                    <?php if ( get_theme_mod('cypress_social_facebook') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_facebook'); ?>"><i class="fab fa-facebook"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_linkedin') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_linkedin'); ?>"><i class="fab fa-linkedin"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_twitter') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_twitter'); ?>"><i class="fab fa-twitter"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_microblog') ) : ?>
                        <a href="<?php echo get_theme_mod('cypress_social_microblog'); ?>"><i class="fab fa-microblog"></i></a>
                    <?php endif; ?>
                    <?php if ( get_theme_mod('cypress_social_instagram') ) : ?>
                    <a href="<?php echo get_theme_mod('cypress_social_instagram'); ?>"><i class="fab fa-instagram"></i></a>
                    <?php endif; ?>
                </p>
            </div>
        </div>
        <!-- Mobile Menu -->
        <div class="mobile-menu">
            <span class="mobile-logo">

            </span>
        </div>
        <!-- Hamburger -->
        <a href="#" class="nav-toggle">
        	<span class="sr-only">Toggle navigation</span>
        	<span class="icon-bar"></span>
        	<span class="icon-bar"></span>
        	<span class="icon-bar"></span>
        </a>
        <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#info">
            <i class="material-icons">info_outline</i>
        </button>
    </header>
</aside>
